@@ -1,8 +1,9 @@
+from dataclasses import asdict
 from typing import Callable, Type
 
 from paperead.repository import DocumentMetadata
-from .. import app
 from paperead import __version__
+from paperead.env import env
 
 from flask import Blueprint, jsonify
 from dateutil.parser import parse
@@ -23,7 +24,8 @@ def buildDocument(type: Type, data: dict):
 @api.route("/index.json")
 def apiinfo():
     return jsonify({
-        "version": __version__
+        "version": __version__,
+        "site": asdict(env.siteConfig)
     })
 
 
